#!/bin/bash

# Copyright (C) 2015 NTT DATA Corporation
# 
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

########################################
#  Local Variable
########################################

FILENAME_POSTFIX=`date '+%Y-%m-%d_%H-%M-%S'`
SUMMARY_FILE="/opt/hinemos_web/var/log/hinemos_web_summary.${FILENAME_POSTFIX}"

echo ""
echo ""
echo "#############################################################"
echo "### Information Gathering Script of Web Client (20150501) ###"
echo "###    Script started at `date '+%Y-%m-%d %T'`              ###"
echo "#############################################################"

echo ""

########################################
#  Function
########################################

function usage {
	echo "Usage: "
	echo "	$0 -vv  : Get information about OS INFORMATION"
	echo "	$0 -vvv : Get information about DETAIL"
	echo "	$0 -md5 : Get information about files's md5sum"
	echo ""
	return 0
}

function init {
	## Hinemos Web env
	SCRIPT_DIR=$(cd $(dirname $0);pwd)
	. ${SCRIPT_DIR}/../../conf/hinemos_web.cfg
}

function os {
	## cat /etc/redhat-release
	echo "### cat /etc/redhat-release ###" | tee -a ${SUMMARY_FILE}
	cat /etc/redhat-release | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	## /proc/PID/environ
	echo "### /proc/PID/environ ###" | tee -a ${SUMMARY_FILE}
	xargs -n 1 -0 < /proc/`cat ${CATALINA_PID}`/environ | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	## systemctl list-dependencies | grep hinemos
	echo "### systemctl list-dependencies | grep hinemos ###" | tee -a ${SUMMARY_FILE}
	systemctl list-dependencies | grep hinemos | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	## systemctl status hinemos_web
	echo "### systemctl status hinemos_web" | tee -a ${SUMMARY_FILE}
	systemctl status hinemos_web | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	## rpm -Va hinemos-web
	echo "### rpm -Va hinemos-web ###" | tee -a ${SUMMARY_FILE}
	rpm -Va hinemos-web | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	## rpm -qa
	echo "### rpm -qa ###" | tee -a ${SUMMARY_FILE}
	rpm -qa | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	## cpuinfo
	echo "### /proc/cpuinfo ###" | tee -a ${SUMMARY_FILE}
	cat /proc/cpuinfo | tee -a ${SUMMARY_FILE}
	echo -e "" | tee -a ${SUMMARY_FILE}
	
	## meminfo
	echo "### /proc/meminfo ###" | tee -a ${SUMMARY_FILE}
	cat /proc/meminfo | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## sar -P ALL
	echo "### sar -P ALL ###" | tee -a ${SUMMARY_FILE}
	sar -P ALL | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## sar -r
	echo "### sar -r ###" | tee -a ${SUMMARY_FILE}
	sar -r | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## sar -n DEV
	echo "### sar -n DEV ###" | tee -a ${SUMMARY_FILE}
	sar -n DEV | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## sar -n EDEV
	echo "### sar -n EDEV ###" | tee -a ${SUMMARY_FILE}
	sar -n EDEV | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## vmstat -n
	echo "### vmstat -n ###" | tee -a ${SUMMARY_FILE}
	vmstat -n | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## iostat -d -x
	echo "### iostat -d -x ###" | tee -a ${SUMMARY_FILE}
	iostat -d -x | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## ps -H auxwww
	echo "### ps -H auxwww ###" | tee -a ${SUMMARY_FILE}
	ps -H auxwww | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}

	netstat --version > /dev/null 2>&1
	if [ $? -eq 0 ]; then
		## netstat -s
		echo "### netstat -s ###" | tee -a ${SUMMARY_FILE}
		netstat -s | tee -a ${SUMMARY_FILE}
		echo -e "\n" | tee -a ${SUMMARY_FILE}

		## netstat -anpo
		echo "### netstat -anpo ###" | tee -a ${SUMMARY_FILE}
		netstat -anpo | tee -a ${SUMMARY_FILE}
		echo -e "\n" | tee -a ${SUMMARY_FILE}
	else
		## ss -s
		echo "### ss -s ###" | tee -a ${SUMMARY_FILE}
		ss -s | tee -a ${SUMMARY_FILE}
		echo -e "\n" | tee -a ${SUMMARY_FILE}

		## ss -anpo
		echo "### ss -anpot ###" | tee -a ${SUMMARY_FILE}
		ss -anpot | tee -a ${SUMMARY_FILE}
		echo -e "\n" | tee -a ${SUMMARY_FILE}
		echo "### ss -anpou ###" | tee -a ${SUMMARY_FILE}
		ss -anpou | tee -a ${SUMMARY_FILE}
		echo -e "\n" | tee -a ${SUMMARY_FILE}
	fi

	## df
	echo "### df ###" | tee -a ${SUMMARY_FILE}
	df | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## df -i
	echo "### df -i ###" | tee -a ${SUMMARY_FILE}
	df -i | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## uptime
	echo "### uptime ###" | tee -a ${SUMMARY_FILE}
	uptime | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## /proc/slabinfo
	echo "### /proc/slabinfo ###" | tee -a ${SUMMARY_FILE}
	cat /proc/slabinfo | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
	
	## /proc/vmstat
	echo "### /proc/vmstat ###" | tee -a ${SUMMARY_FILE}
	cat /proc/vmstat | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
}

function md5sum {
	## md5sum
	echo "### md5sum ###" | tee -a ${SUMMARY_FILE}
	cd ${HINEMOS_WEB_HOME}
	find `ls --ignore={var,tomcat}` -type f | xargs md5sum | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
}

function detail {
	## lsof
	echo "### lsof ###" | tee -a ${SUMMARY_FILE}
	lsof | tee -a ${SUMMARY_FILE}
	echo -e "\n" | tee -a ${SUMMARY_FILE}
  
	md5sum
}

########################################
# Main
########################################

# check parameters
if [ $# -eq 0 ]; then
	usage
	exit 1
fi
for OPT in $@; do
	case $OPT in
		--help|-h)
			usage
			exit 0
			;;
	esac
done

case "$@" in
	-vv)
		init
		os
		;;
	-vvv)
		init
		os
		detail
		;;
	-md5)
		init
		md5sum
		;;
	*)
		usage
		exit 1
esac

echo "### Hinemos Web Summary ###"
echo ${SUMMARY_FILE}

echo ""
echo "###################################################"
echo "###    Script ended at `date '+%Y-%m-%d %T'`    ###"
echo "###################################################"

exit 0
